@@ -17,9 +17,14 @@ def get_context() -> str:
 def autowired(func: Callable) -> Callable:
     def wrapper(*args, **kwargs):
         func_annotation: Dict[str, Type[T]] = inspect.getfullargspec(func).annotations
+        context: str = get_context()
         for key_param, key_type in func_annotation.items():
-            if key_type in services:
-                kwargs[key_param] = services_dict.get(get_context(), services_dict[DEFAULT])[key_type]()
+            param_context: str = (  # Get context for specific parameter
+                context if context in services_dict.keys() and key_type in services_dict[context].keys() else DEFAULT
+            )
+            if key_type not in services_dict.get(param_context, {}).keys():  #
+                raise ValueError
+            kwargs[key_param] = services_dict.get(param_context)[key_type]()
         func(*args, **kwargs)
 
     return wrapper
