@@ -1,5 +1,5 @@
 import glob
-import importlib
+import importlib.util
 from pathlib import Path
 from typing import NoReturn
 
